NEATEST: Evolving Neural Networks Through Augmenting Topologies with Evolution Strategy Training
===============================================================================================

It is NEAT but the weights are trained with Natural Evolution Strategy and
the weights are shared across genomes.

![](videos/DoubleInvertedPendulum.gif) ![](videos/LunarLander.gif)

# Requirements
```
numpy
cloudpickle
```

# Install
```
pip install nesneat
```

## Optional
```
matplotlib # To draw networks
mpi4py # For parallelization
gym # For examples
```

# Usage
Check https://github.com/goktug97/NEATEST/examples

